/* eslint-disable no-param-reassign */
import { useCallback, useLayoutEffect, useRef } from 'react';
import ResizeObserver from 'resize-observer-polyfill';
import debounce from '../../utils/debounce';
import { LINE_CLASSNAME } from './constants';
export default ({ root, autoScroll, lineIndex, lines, verticalSpace, }) => {
    const indexMapRef = useRef(new Map());
    const scrollToCurrentLine = useCallback(() => {
        if (!root) {
            return;
        }
        const indexMap = indexMapRef.current.get(lineIndex);
        if (indexMap) {
            root.scrollTop =
                indexMap.offsetTop - root.clientHeight * 0.5 + indexMap.height / 2;
        }
        else {
            root.scrollTop = 0;
        }
    }, [lineIndex, root]);
    useLayoutEffect(() => {
        if (root) {
            const caculateIndexMap = () => {
                const indexMap = new Map();
                const lrcLineNodeList = root.querySelectorAll(`.${LINE_CLASSNAME}`);
                for (let i = 0, { length } = lrcLineNodeList; i < length; i += 1) {
                    const lrcLineNode = lrcLineNodeList[i];
                    indexMap.set(i, {
                        height: lrcLineNode.clientHeight,
                        offsetTop: lrcLineNode.offsetTop,
                    });
                }
                indexMapRef.current = indexMap;
            };
            caculateIndexMap();
            const resizeDetector = new ResizeObserver(debounce(caculateIndexMap));
            resizeDetector.observe(root);
            return () => resizeDetector.disconnect();
        }
    }, [root, lines, verticalSpace]);
    useLayoutEffect(() => {
        if (autoScroll) {
            scrollToCurrentLine();
        }
    }, [autoScroll, scrollToCurrentLine, lines, verticalSpace]);
};
